@@ -216,9 +216,7 @@ class Agent(Insight, Channel, Catalog, Dataset):
         response.raise_for_status()
         r = response.json()
 
-    def _load_dataset(self, datasetSlug):
-
-        dataset = self.get_dataset_by_slug(self._agentId, datasetSlug)
+    def _load_dataset(self, dataset):
 
         s = requests.Session()
         s.keep_alive = False
@@ -243,9 +241,12 @@ class Agent(Insight, Channel, Catalog, Dataset):
         '''
 
         dataset = self.get_dataset_by_slug(self._agentId, dataset_slug)
+        if(dataset == None):
+            logging.error("Please insert a correct dataset slug")
+            return
 
         if(aliases==[]):
-            return self._load_dataset(dataset_slug)
+            return self._load_dataset(dataset)
 
         dataset_id = dataset["id"]
         url_get = self.smart_insight_url + "/composed_queries?datasetId=" + dataset_id
