@@ -6,7 +6,7 @@ from askdata.insight import Insight
 from askdata.channel import Channel
 from askdata.catalog import Catalog
 from askdata.dataset import Dataset
-from askdata.security import SignUp
+import pandas as pd
 from requests.adapters import HTTPAdapter
 from urllib3.util.retry import Retry
 from typing import TYPE_CHECKING
@@ -179,7 +179,7 @@ class Insight_Definition:
     def add_list(self, query_id, title_parameter, description_parameter, action_label,
                   action_url, max_results,list_name="List"):
         position = (len(self.components))
-        list_id = self.add_component("list", position)
+        list_id = self.add_component(type="list", position=position)
         self.edit_list(list_id, query_id, title_parameter,
                        description_parameter, action_label, action_url, max_results, list_name)
         return list_id
@@ -221,6 +221,89 @@ class Insight_Definition:
         r.raise_for_status()
         self.components = r.json()["components"]
 
+    def add_data(self, df:pd.DataFrame, parameters_settings:list=[]):
+        position = (len(self.components))
+        data_id = self.add_component("data", position)
+        self.edit_data(data_id, df)
+        if(parameters_settings!=[]):
+            for i in range(len(parameters_settings)):
+               self.edit_data_entity(data_id, i, parameters_settings[i])
+        return data_id
+
+    def edit_data(self, data_id: str, df: pd.DataFrame, index:bool=False):
+
+        body = df.to_json(orient="table", index=index)
+        url = self.smart_insight_url+"/definitions/"+self.definition_id+"/data_queries/"+data_id+"/data"
+        logging.info("URL: {}".format(url))
+        s = requests.Session()
+        s.keep_alive = False
+        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
+        s.mount('https://', HTTPAdapter(max_retries=retries))
+
+        headers = {
+            "Content-Type": "application/json",
+            "Authorization": "Bearer" + " " + self._token
+        }
+        r = s.put(url=url, data=body, headers=headers)
+        r.raise_for_status()
+        self.components = r.json()["components"]
+
+
+    def load_data_entities(self, data_id):
+        url = self.smart_insight_url+"/definitions/"+self.definition_id+"/queries"
+        logging.info("URL {}".format(url))
+        s = requests.Session()
+        s.keep_alive = False
+        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
+        s.mount('https://', HTTPAdapter(max_retries=retries))
+        headers = {"Authorization": "Bearer" + " " + self._token}
+        response = s.get(url=url, headers=headers)
+        response.raise_for_status()
+        r = response.json()
+        for query in r:
+            if(query["id"]==data_id):
+                query_data = query
+                return query_data["entities"]
+        logging.info("No query with id {} found".format(data_id))
+        return []
+
+    #TODO Metodo per ottenere una specifica entity e relativa posizione
+
+    def edit_data_entity(self, data_id, entity_position:int, entity_settings:dict):
+
+        url = self.smart_insight_url+"/definitions/"+self.definition_id+"/queries/"+data_id+"/columns/"+str(entity_position)
+
+        s = requests.Session()
+        s.keep_alive = False
+        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
+        s.mount('https://', HTTPAdapter(max_retries=retries))
+
+        headers = {
+            "Content-Type": "application/json",
+            "Authorization": "Bearer" + " " + self._token
+        }
+        r = s.put(url=url, json=entity_settings, headers=headers)
+        r.raise_for_status()
+
+    def edit_data_name(self, data_id, component_name):
+        url = self.smart_insight_url+"/definitions/"+self.definition_id+"/data_queries/"+data_id
+        body = {
+            "name": component_name
+        }
+        logging.info("URL: {}".format(url))
+
+        s = requests.Session()
+        s.keep_alive = False
+        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
+        s.mount('https://', HTTPAdapter(max_retries=retries))
+
+        headers = {
+            "Content-Type": "application/json",
+            "Authorization": "Bearer" + " " + self._token
+        }
+        r = s.put(url=url, json=body, headers=headers)
+        r.raise_for_status()
+        self.components = r.json()["components"]
 
     def add_cta(self, cta_label, cta_url):
         position = (len(self.components))
