@@ -24,6 +24,11 @@ class TimeDimensionGranularity(Enum):
     interval = auto()
 
 
+class SignOperator(Enum):
+    POS = auto()
+    NEG = auto()
+
+
 @dataclass
 class Field:
     column: str
